@@ -33,14 +33,11 @@
 //      dan             Dan Holloway <dholloway@gso.uri.edu>
 //      reza            Reza Nekovei <reza@intcomm.net>
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: Connect.cc,v 1.134 2005/04/07 22:32:47 jimg Exp $" };
+    { "$Id: Connect.cc 12072 2005-09-06 18:41:25Z jimg $" };
 
 #include <stdio.h>
 #ifndef WIN32
@@ -259,7 +256,7 @@ Connect::Connect(const string &n, string uname, string password)
     default. 
     @param uname Use this username for authentication. Null by default.
     @param password Passwrod to use for authentication. Null by default. */
-Connect::Connect(const string &n, bool www_verbose_errors, 
+Connect::Connect(const string &n, bool /* www_verbose_errors; unused */, 
 		 bool accept_deflate, string uname, string password) 
     throw (Error, InternalErr)
     : d_http(0), d_version("unknown")
@@ -411,6 +408,64 @@ configured, or that the URL has changed.");
     delete rs; rs = 0;
 }
 
+/** Reads the DAS corresponding to the dataset in the Connect
+    object's URL. Although DODS does not support usig CEs with DAS
+    requests, if present in the Connect object's instance, they will be
+    escaped and passed as the query string of the request.
+
+    Different from request_das method in that this method uses the URL as
+    given without attaching .das or projections or selections.
+
+    @brief Get the DAS from a server.
+    @param das Result. */
+void
+Connect::request_das_url(DAS &das) throw(Error, InternalErr)
+{
+    string use_url = _URL + "?" + _proj + _sel ;
+    Response *rs = 0;
+    try {
+	rs = d_http->fetch_url(use_url);
+    }
+    catch (Error &e) {
+	delete rs; rs = 0;
+	throw e;
+    }
+
+    d_version = rs->get_version(); // Improve this design!
+
+    switch (rs->get_type()) {
+      case dods_error: {
+	  if (!_error.parse(rs->get_stream())) {
+	      throw InternalErr(__FILE__, __LINE__, 
+			"Could not parse error returned from server.");
+	      break;
+	  }
+	  throw _error;
+	  break;
+      }
+
+      case web_error:
+	// We should never get here; a web error should be picked up read_url
+	// (called by fetch_url) and result in a thrown Error object.
+	break;
+
+      case dods_das:
+      default:
+	// DAS::parse throws an exception on error.
+	try {
+	    das.parse(rs->get_stream()); // read and parse the das from a file 
+	}
+	catch (Error &e) {
+	    delete rs; rs = 0;
+	    throw e;
+	}
+	    
+	break;
+    }
+
+    delete rs; rs = 0;
+}
+
 /** Reads the DDS corresponding to the dataset in the Connect object's URL.
     If present in the Connect object's instance, a CE will be escaped,
     combined with \c expr and passed as the query string of the request.
@@ -493,6 +548,70 @@ configured, or that the URL has changed.");
     delete rs; rs = 0;
 }
 
+/** Reads the DDS corresponding to the dataset in the Connect object's URL.
+    If present in the Connect object's instance, a CE will be escaped,
+    combined with \c expr and passed as the query string of the request.
+
+    Different from request_dds method above in that this method assumes
+    URL is complete and does not add anything to the command, such as .dds
+    or projections or selections.
+
+    @note If you need the DDS to hold specializations of the type classes,
+    be sure to include the factory class which will instantiate those
+    specializations in the DDS. Either pass a pointer to the factory to
+    DDS constructor or use the DDS::set_factory() method after the 
+    object is built.
+
+    @brief Get the DDS from a server.
+    @param dds Result.
+    @param expr Send this constraint expression to the server. */
+void
+Connect::request_dds_url(DDS &dds) throw(Error, InternalErr)
+{
+    string use_url = _URL + "?" + _proj + _sel ;
+    Response *rs = 0;
+    try {
+	rs = d_http->fetch_url(use_url);
+    }
+    catch (Error &e) {
+	delete rs; rs = 0;
+	throw e;
+    }
+
+    d_version = rs->get_version(); // Improve this design!
+
+    switch (rs->get_type()) {
+      case dods_error: {
+	  if (!_error.parse(rs->get_stream())) {
+	      throw InternalErr(__FILE__, __LINE__, 
+			"Could not parse error returned from server.");
+	      break;
+	  }
+	  throw _error;
+	  break;
+      }
+
+      case web_error:
+	// We should never get here; a web error should be picked up read_url
+	// (called by fetch_url) and result in a thrown Error object.
+	break;
+
+      case dods_dds:
+      default:
+	// DDS::prase throws an exception on error.
+	try {
+	    dds.parse(rs->get_stream()); // read and parse the dds from a file 
+	}
+	catch (Error &e) {
+	    delete rs; rs = 0;
+	    throw e;
+	}
+	break;
+    }
+
+    delete rs; rs = 0;
+}
+
 /** Reads the DataDDS object corresponding to the dataset in the Connect
     object's URL. If present in the Connect object's instance, a CE will be
     escaped, combined with \c expr and passed as the query string of the
@@ -539,6 +658,42 @@ Connect::request_data(DataDDS &data, string expr) throw(Error, InternalErr)
     }
 }
 
+/** Reads the DataDDS object corresponding to the dataset in the Connect
+    object's URL. If present in the Connect object's instance, a CE will be
+    escaped, combined with \c expr and passed as the query string of the
+    request. The result is a DataDDS which contains the data values bound to
+    variables.
+
+    Different from request_data in that this method uses the syntax of the
+    new OPeNDAP server commands using dispatch
+
+    @note If you need the DataDDS to hold specializations of the type classes,
+    be sure to include the factory class which will instantiate those
+    specializations in the DataDDS. Either pass a pointer to the factory to
+    DataDDS constructor or use the DDS::set_factory() method after the 
+    object is built.
+    
+    @brief Get the DAS from a server.
+    @param data Result.
+    @param expr Send this constraint expression to the server. */
+void
+Connect::request_data_url(DataDDS &data) throw(Error, InternalErr)
+{
+    string use_url = _URL + "?" + _proj + _sel ;
+    Response *rs = 0;
+    // We need to catch Error exceptions to ensure calling close_output.
+    try {
+	rs = d_http->fetch_url(use_url);
+	d_version = rs->get_version(); // Improve this design!
+	process_data(data, rs);
+	delete rs; rs = 0;
+    }
+    catch (Error &e) {
+	delete rs; rs = 0;
+	throw e;
+    }
+}
+
 /** This is a place holder. A better implementation for reading objects from
     the local file store is to write FileConnect and have it support the same
     interface as HTTPConnect.
@@ -673,7 +828,7 @@ Connect::is_cache_enabled()
     return status;
 }
 
-#ifdef DEFAULT_BASETYPE_FACTORY
+// #ifdef DEFAULT_BASETYPE_FACTORY
 /** @name Remove these...
     All of these are deprecated and will be removed in a future version of
     this code. */
@@ -742,7 +897,7 @@ Connect::error()
     return _error;
 }
 //@}
-#endif
+// #endif
 
 // $Log: Connect.cc,v $
 // Revision 1.134  2005/04/07 22:32:47  jimg
