@@ -34,13 +34,10 @@
 //
 // jhrg 7/25/94
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used ={"$Id: DAS.cc,v 1.43 2004/07/07 21:08:47 jimg Exp $"};
+static char rcsid[] not_used ={"$Id: DAS.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
 #include <stdio.h>
 #ifdef WIN32
@@ -578,7 +575,7 @@ DAS::print(FILE *out, bool dereference)
 //
 // Revision 1.13  1995/05/10  13:45:11  jimg
 // Changed the name of the configuration header file from `config.h' to
-// `config_dap.h' so that other libraries could have header files which were
+// `config.h' so that other libraries could have header files which were
 // installed in the DODS include directory without overwriting this one. Each
 // config header should follow the convention config_<name>.h.
 //
