@@ -31,13 +31,10 @@
 
 // The Grid Selection Expression Clause class.
 
-#ifdef _GNUG_
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
-static char id[] not_used = {"$Id: GSEClause.cc,v 1.17 2004/07/07 21:08:47 jimg Exp $"};
+static char id[] not_used = {"$Id: GSEClause.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
 #include <iostream>
 #include <sstream>
@@ -68,12 +65,12 @@ GSEClause::GSEClause()
   throw InternalErr(__FILE__, __LINE__, "default ctor called for GSEClause");
 }
 
-GSEClause::GSEClause(const GSEClause &param)
+GSEClause::GSEClause(const GSEClause &)
 {
   throw InternalErr(__FILE__, __LINE__, "copy ctor called for GSEClause");
 }
 
-GSEClause &GSEClause::operator=(GSEClause &rhs)
+GSEClause &GSEClause::operator=(GSEClause &)
 {
   throw InternalErr(__FILE__, __LINE__, "assigment called for GSEClause");
 }
@@ -278,12 +275,12 @@ GSEClause::GSEClause(Grid *grid, const string &map, const double value1,
 }
 
 /** @brief Create an instance using a grid and an expression. */
-GSEClause::GSEClause(Grid *grid, const string &expr)
+GSEClause::GSEClause(Grid *, const string &)
 {
 }
 
 /** @brief Create an instance using a grid and an expression. */
-GSEClause::GSEClause(Grid *grid, char *expr)
+GSEClause::GSEClause(Grid *, char *)
 {
 }
 
