@@ -33,7 +33,7 @@
 //
 // jhrg 9/15/94
 
-#include "config_dap.h"
+#include "config.h"
 
 #include <functional>
 #include <algorithm>
@@ -46,9 +46,6 @@
 #include "escaping.h"
 #include "BTIterAdapter.h"
 
-#ifdef TRACE_NEW
-#include "trace_new.h"
-#endif
 
 using namespace std;
 
@@ -566,11 +563,11 @@ Grid::print_decl(ostream &os, string space, bool print_semi,
 	// we have a valid Grid object; send it as such.
 	os << space << type_name() << " {" << endl;
 
-	os << space << " ARRAY:" << endl;
+	os << space << "  Array:" << endl;
 	_array_var->print_decl(os, space + "    ", true, constraint_info,
 			       constrained);
 
-	os << space << " MAPS:" << endl;
+	os << space << "  Maps:" << endl;
 	for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++)
 	{
 	    (*i)->print_decl(os, space + "    ", true,
@@ -638,11 +635,11 @@ Grid::print_decl(FILE *out, string space, bool print_semi,
 	// we have a valid Grid object; send it as such.
 	fprintf( out, "%s%s {\n", space.c_str(), type_name().c_str() ) ;
 
-	fprintf( out, "%s ARRAY:\n", space.c_str() ) ;
+	fprintf( out, "%s  Array:\n", space.c_str() ) ;
 	_array_var->print_decl(out, space + "    ", true, constraint_info,
 			       constrained);
 
-	fprintf( out, "%s MAPS:\n", space.c_str() ) ;
+	fprintf( out, "%s  Maps:\n", space.c_str() ) ;
 	for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++)
 	{
 	    (*i)->print_decl(out, space + "    ", true,
@@ -699,7 +696,7 @@ Grid::print_xml(FILE *out, string space, bool constrained)
     for_each(map_begin(), map_end(),
 	     PrintMapField(out, space + "    ", constrained));
 	
-    fprintf(out, "%s<Grid/>\n", space.c_str());
+    fprintf(out, "%s</Grid>\n", space.c_str());
 }
 
 void 
@@ -716,12 +713,12 @@ Grid::print_val(ostream &os, string space, bool print_decl_p)
     // the value of this function should be ignored. 4/6/2000 jhrg
     bool pyg = projection_yields_grid(); // hack 12/1/99 jhrg
     if (pyg || !send_p())
-	os << "{ ARRAY: ";
+	os << "{  Array: ";
     else
 	os << "{";
     _array_var->print_val(os, "", false);
     if (pyg || !send_p())
-	os << " MAPS: ";
+	os << "  Maps: ";
     for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); 
 	 i++, (void)(i != _map_vars.end() && os << ", "))
     {
@@ -747,12 +744,12 @@ Grid::print_val(FILE *out, string space, bool print_decl_p)
     // the value of this function should be ignored. 4/6/2000 jhrg
     bool pyg = projection_yields_grid(); // hack 12/1/99 jhrg
     if (pyg || !send_p())
-	fprintf( out, "{ ARRAY: " ) ;
+	fprintf( out, "{  Array: " ) ;
     else
 	fprintf( out, "{" ) ;
     _array_var->print_val(out, "", false);
     if (pyg || !send_p())
-	fprintf( out, " MAPS: " ) ;
+	fprintf( out, "  Maps: " ) ;
     for( Map_citer i = _map_vars.begin(); i != _map_vars.end(); 
 	 i++, (void)(i != _map_vars.end() && fprintf( out, ", " ) ) )
     {
@@ -1247,16 +1244,16 @@ Grid::check_semantics(string &msg, bool all)
 // Added copyright notice.
 //
 // Revision 1.11  1995/05/10  15:34:00  jimg
-// Failed to change `config.h' to `config_dap.h' in these files.
+// Failed to change `config.h' to `config.h' in these files.
 //
 // Revision 1.10  1995/05/10  13:45:18  jimg
 // Changed the name of the configuration header file from `config.h' to
-// `config_dap.h' so that other libraries could have header files which were
+// `config.h' so that other libraries could have header files which were
 // installed in the DODS include directory without overwriting this one. Each
 // config header should follow the convention config_<name>.h.
 //
 // Revision 1.9  1995/03/16  17:29:10  jimg
-// Added include config_dap.h to top of include list.
+// Added include config.h to top of include list.
 // Added TRACE_NEW switched dbnew includes.
 // Fixed bug in read_val() where **val was passed incorrectly to
 // subordinate read_val() calls.
