@@ -23,11 +23,7 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
-#ifdef __GNUG__
-// #pragma implementation
-#endif
-
-#include "config_dap.h"
+#include "config.h"
 
 #include <stdio.h>
 #include <pthread.h>
@@ -1164,7 +1160,11 @@ HTTPCache::set_max_size(unsigned long size)
     try {
 	unsigned long new_size = size < MIN_CACHE_TOTAL_SIZE ?
 	    MIN_CACHE_TOTAL_SIZE*MEGA : 
-	    (size > UINT_MAX || size < 0 ? UINT_MAX : size * MEGA);
+            (size > ULONG_MAX ? ULONG_MAX : size * MEGA);
+#if 0
+            // original code. UINT --> ULONG; Removed size < 0
+            (size > UINT_MAX || size < 0 ? UINT_MAX : size * MEGA);
+#endif
 	unsigned long old_size = d_total_size;
 	d_total_size = new_size;
 	d_folder_size = d_total_size/CACHE_FOLDER_PCT;
@@ -1380,7 +1380,8 @@ HTTPCache::get_cache_control()
 
     A private method.
 
-    @param hash The hash value (i.e., directory name).
+    @param hash The hash value (i.e., directory name). An integer between 0
+    and CACHE_TABLE_SIZE (See HTTPCache.h).
     @return The pathname to the directory (even if it already existed).
     @exception Error Thrown if the directory cannot be created.*/
 
@@ -1573,6 +1574,9 @@ HTTPCache::is_url_in_cache(const string &url)
 /** Is the header a hop by hop header? If so, we're not supposed to store it
     in the cache. See RFC 2616, Section 13.5.1.
 
+    @todo Export this function so that HTTPCacheTest can use it and won't
+    maintain its own copy.
+
     @return True if the header is, otherwise False. */
 
 static inline bool
@@ -2483,7 +2487,7 @@ HTTPCache::purge_cache() throw(Error)
 //
 // Revision 1.7  2003/03/13 23:55:57  jimg
 // Significant changes regarding the mutex code. I found out that since
-// config_dap.h was not being included, the mutex code was never built! Once
+// config.h was not being included, the mutex code was never built! Once
 // built, I found a bunch of deadlocks. Many of the methods had to be modified
 // to fix this/these problem(s).
 //
