@@ -23,14 +23,11 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc,v 1.22 2005/04/21 17:51:34 jimg Exp $" };
+    { "$Id: HTTPConnect.cc 11932 2005-08-11 22:26:27Z jimg $" };
 
 #include <stdio.h>
 
@@ -48,7 +45,7 @@ static char rcsid[] not_used =
 #include <iterator>
 
 #include "debug.h"
-#include "Regex.h"
+#include "GNURegex.h"
 #include "HTTPCache.h"
 #include "HTTPConnect.h"
 #include "RCReader.h"
@@ -209,7 +206,7 @@ save_raw_http_headers(void *ptr, size_t size, size_t nmemb, void *resp_hdrs)
 
 /** A libcurl callback for debugging protocol issues. */
 static int
-curl_debug(CURL *curl, curl_infotype info, char *msg, size_t size, void  *data)
+curl_debug(CURL *, curl_infotype info, char *msg, size_t size, void  *)
 {
     string message(msg, size);
 
@@ -495,9 +492,13 @@ HTTPConnect::fetch_url(const string &url) throw(Error, InternalErr)
     HTTPResponse *stream;
 
     if (d_http_cache && d_http_cache->is_cache_enabled())
+    {
 	stream = caching_fetch_url(url);
+    }
     else
+    {
 	stream = plain_fetch_url(url);
+    }
     
     ParseHeader parser;
 
@@ -797,7 +798,7 @@ HTTPConnect::set_credentials(const string &u, const string &p)
 // work.
 //
 // Revision 1.20  2005/04/15 21:17:23  jimg
-// Remove include of config_dap.h from HTTPCache.h.
+// Remove include of config.h from HTTPCache.h.
 //
 // Revision 1.19  2005/01/28 17:25:12  jimg
 // Resolved conflicts from merge with release-3-4-9
