@@ -31,13 +31,10 @@
 
 // Implementation for the InternalErr class.
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used = {"$Id: InternalErr.cc,v 1.15 2004/07/07 21:08:47 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: InternalErr.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
 #include <stdio.h>
 
