@@ -34,9 +34,9 @@
 // definitions must follow *both* rvalue's and func_rvalue's declarations.
 // jhrg 3/4/96
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used = {"$Id: RValue.cc,v 1.15 2005/01/28 17:25:12 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: RValue.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
 #include <assert.h>
 
