@@ -42,9 +42,6 @@
 #ifndef _sequence_h
 #define _sequence_h 1
 
-#ifdef _GNUG_
-// #pragma interface
-#endif
 
 #include <vector>
 #include "Pix.h"
@@ -57,10 +54,6 @@
 #include "Constructor.h"
 #endif
 
-#if defined(TRACE_NEW) && !defined(_trace_new_h)
-#include "trace_new.h"
-#endif
-
 /** The type BaseTypeRow is used to store single rows of values in an
     instance of Sequence. Values are stored in instances of BaseType. */
 typedef vector<BaseType *> BaseTypeRow;
