@@ -33,11 +33,8 @@
 //
 // jhrg 9/14/94
 
-#ifdef _GNUG_
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
 #include <stdlib.h>
 
@@ -50,9 +47,6 @@
 #include "BTIterAdapter.h"
 #endif
 
-#ifdef TRACE_NEW
-#include "trace_new.h"
-#endif
 
 using std::cerr;
 using std::endl;
@@ -574,7 +568,7 @@ Structure::print_val(FILE *out, string space, bool print_decl_p)
     @see Sequence::print_all_vals
 */
 void
-Structure::print_all_vals(ostream &os, XDR *src, DDS *dds, string space, bool print_decl_p)
+Structure::print_all_vals(ostream &os, XDR *, DDS *, string space, bool print_decl_p)
 {
     print_val(os, space, print_decl_p);
 
@@ -628,7 +622,7 @@ Structure::print_all_vals(ostream &os, XDR *src, DDS *dds, string space, bool pr
 // No longer a problem as Sequences are now read in full. 05/16/03 jhrg
 
 void
-Structure::print_all_vals(FILE *out, XDR *src, DDS *dds, string space, bool print_decl_p)
+Structure::print_all_vals(FILE *out, XDR *, DDS *, string space, bool print_decl_p)
 {
     print_val(out, space, print_decl_p);
 
@@ -1067,16 +1061,16 @@ Structure::check_semantics(string &msg, bool all)
 // Added copyright notice.
 //
 // Revision 1.12  1995/05/10  15:34:06  jimg
-// Failed to change `config.h' to `config_dap.h' in these files.
+// Failed to change `config.h' to `config.h' in these files.
 //
 // Revision 1.11  1995/05/10  13:45:31  jimg
 // Changed the name of the configuration header file from `config.h' to
-// `config_dap.h' so that other libraries could have header files which were
+// `config.h' so that other libraries could have header files which were
 // installed in the DODS include directory without overwriting this one. Each
 // config header should follow the convention config_<name>.h.
 //
 // Revision 1.10  1995/03/16  17:29:12  jimg
-// Added include config_dap.h to top of include list.
+// Added include config.h to top of include list.
 // Added TRACE_NEW switched dbnew includes.
 // Fixed bug in read_val() where **val was passed incorrectly to
 // subordinate read_val() calls.
