@@ -33,13 +33,10 @@
 //
 // jhrg 9/7/94
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used = {"$Id: UInt16.cc,v 1.24 2004/07/07 21:08:48 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: UInt16.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
 #include <stdlib.h>
 
@@ -53,9 +50,6 @@ static char rcsid[] not_used = {"$Id: UInt16.cc,v 1.24 2004/07/07 21:08:48 jimg
 #include "debug.h"
 #include "InternalErr.h"
 
-#ifdef TRACE_NEW
-#include "trace_new.h"
-#endif
 
 #ifdef WIN32
 #include <xdr.h>
