@@ -34,13 +34,10 @@
 //
 // 11/21/95 jhrg
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used = {"$Id: Vector.cc,v 1.60 2005/04/07 22:32:47 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: Vector.cc 11932 2005-08-11 22:26:27Z jimg $"};
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
 
 #include <algorithm>
 
@@ -50,9 +47,6 @@ static char rcsid[] not_used = {"$Id: Vector.cc,v 1.60 2005/04/07 22:32:47 jimg
 #include "debug.h"
 #include "InternalErr.h"
 
-#ifdef TRACE_NEW
-#include "trace_new.h"
-#endif
 
 using std::cerr;
 using std::endl;
@@ -404,7 +398,7 @@ bool
 Vector::serialize(const string &dataset, DDS &dds, XDR *sink, 
 		  bool ce_eval)
 {
-	int i = 0;
+    int i = 0;
 
     dds.timeout_on();
 
@@ -844,8 +838,11 @@ Vector::set_vec(unsigned int i, BaseType *val)
     // This is a public method which allows users to set the elements
     // of *this* vector. Passing an invalid index, a NULL pointer or 
     // missmatching the vector type are internal errors.
+#if 0
+    // 'i' is unsigned. jhrg 8/9/05
     if (i<0)
 	throw InternalErr(__FILE__, __LINE__, "Invalid data: negative index.");
+#endif
     if (i>=static_cast<unsigned int>(_length))
         throw InternalErr(__FILE__, __LINE__, "Invalid data: index too large.");
     if (!val)
