@@ -33,9 +33,9 @@
 //
 // jhrg 9/21/94
 
-#include "config_dap.h"
+#include "config.h"
 
-static char rcsid[] not_used = {"$Id: util.cc,v 1.83 2005/04/22 23:31:40 jimg Exp $"};
+static char rcsid[] not_used = {"$Id: util.cc 12284 2005-09-30 21:49:51Z jimg $"};
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -64,8 +64,6 @@ static char rcsid[] not_used = {"$Id: util.cc,v 1.83 2005/04/22 23:31:40 jimg Ex
 #include <algorithm>
 #include <stdexcept>
 
-#include "Regex.h"
-
 #include "BaseType.h"
 #include "Str.h"
 #include "Url.h"
@@ -76,15 +74,20 @@ static char rcsid[] not_used = {"$Id: util.cc,v 1.83 2005/04/22 23:31:40 jimg Ex
 #include "util.h"
 #include "debug.h"
 
-#ifdef TRACE_NEW
-#include "trace_new.h"
-#endif
 
 using namespace std;
 
 // Remove spaces from the start of a URL and from the start of any constraint
 // expression it contains. 4/7/98 jhrg
 
+/** Removed spaces from the front of a URL and also from the front of the CE.
+    This function assumes that there are no holes in both the URL and the CE.
+    It will remove \i leading space, but not other spaces.
+
+    @todo Is this still needed? This function may predate the switch from
+    libwww to libcurl and the latter may not need to have spaces removed.
+    @param name The URL to process
+    @return Returns a new string object that contains the pruned URL. */
 string 
 prune_spaces(const string &name)
 {
@@ -515,12 +518,12 @@ double_to_string(const double &num)
 }
 
 // Get the version number of the core software. Defining this means that
-// clients of the DAP don't have to rely on config_dap.h for the version
+// clients of the DAP don't have to rely on config.h for the version
 // number. 
 string
 dap_version()
 {
-    return (string)DVR + ": compiled on " + __DATE__ + ":" + __TIME__ ;
+    return (string)"OPeNDAP DAP/" + libdap_version() + ": compiled on " + __DATE__ + ":" + __TIME__ ;
 }
 
 // Given a pathname, return the file at the end of the path. This is used
@@ -612,6 +615,9 @@ file_to_string(FILE *fp)
 }
 
 // $Log: util.cc,v $
+// Revision 1.84  2005/05/17 17:37:55  pwest
+// updated dap_version using libdap_version
+//
 // Revision 1.83  2005/04/22 23:31:40  jimg
 // Version 3.5.0 builds; passes most tests
 //
@@ -1065,11 +1071,11 @@ file_to_string(FILE *fp)
 // Added copyright notice.
 //
 // Revision 1.11  1995/05/10  15:34:09  jimg
-// Failed to change `config.h' to `config_dap.h' in these files.
+// Failed to change `config.h' to `config.h' in these files.
 //
 // Revision 1.10  1995/05/10  13:45:46  jimg
 // Changed the name of the configuration header file from `config.h' to
-// `config_dap.h' so that other libraries could have header files which were
+// `config.h' so that other libraries could have header files which were
 // installed in the DODS include directory without overwriting this one. Each
 // config header should follow the convention config_<name>.h.
 //
